:mod:`langacore.kit.django.common.templatetags.strings`
=======================================================


.. automodule:: langacore.kit.django.common.templatetags.strings


Functions
----------

.. autofunction:: slugify

.. autofunction:: strike_empty

.. autofunction:: title

.. autofunction:: transliterate

